fn publish_index_version(region: &MitoRegionRef, next: Arc<SeriesIndexVersion>)Expand description
Publishes the snapshot and retires series files absent from the new version.
fn publish_index_version(region: &MitoRegionRef, next: Arc<SeriesIndexVersion>)Publishes the snapshot and retires series files absent from the new version.