async fn build_index_version(
worker_id: u32,
store: &ObjectStore,
region: &MitoRegionRef,
version: &Arc<Version>,
requested_bucket_width: Duration,
now_ms: i64,
purger: &IndexFilePurger,
unpublished: &mut UnpublishedSeriesFiles,
enable_range_index: bool,
allow_builds: bool,
) -> Result<(Option<SeriesIndexVersion>, ReconcileStats)>Expand description
Builds a changed snapshot, retaining reusable indexes and removing obsolete coverage.
Returns None when no range or series indexes were added or removed.